@@ -11,4 +11,4 @@ LUA_SIZE_T_LENGTH = 4
 LUA_NUMBER_LENGTH = 8
 
 LUA_BYTEORDER = "little"
-LUA_STR_ENCODING = "ascii"
+LUA_STR_ENCODING = "utf-8"
